from distutils.core import setup
setup(
                        name                    ='zhouzhiyong_test',
                        version                 ='1.2.0',
                        py_modules          =['zhouzhiyong_test'],
                        author                  ='zhouzhiyong',
                        author_email        ='756981877@qq.com',
                        url                         ='http://user.qzone.qq.com/756981877',
                        description             ='打印列表（包括镶嵌），并且单词首字母大写',
                )
    
                        
